Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(162)

Unified Diff: content/public/browser/security_style_explanations.h

Issue 2400673003: Remove SSLStatus::security_style member and content::SecurityStyle (Closed)
Patch Set: more curly braces Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/security_style_util.cc ('k') | content/public/browser/security_style_explanations.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/security_style_explanations.h
diff --git a/content/public/browser/security_style_explanations.h b/content/public/browser/security_style_explanations.h
index e08e0446ef81eace5bf9ace0d1cfdfc0a19ecd88..b97aa6016bb95f2556380a4b7eb5ce2f12ea06b2 100644
--- a/content/public/browser/security_style_explanations.h
+++ b/content/public/browser/security_style_explanations.h
@@ -9,7 +9,7 @@
#include "content/common/content_export.h"
#include "content/public/browser/security_style_explanation.h"
-#include "content/public/common/security_style.h"
+#include "third_party/WebKit/public/platform/WebSecurityStyle.h"
namespace content {
@@ -52,11 +52,11 @@ struct SecurityStyleExplanations {
// These values are used to convey the effect
// that insecure content has on the overall SecurityStyle of the page;
// for example, a |displayed_insecure_content_style| value of
// SECURITY_STYLE_UNAUTHENTICATED indicates that the page's overall
// SecurityStyle will be downgraded to UNAUTHENTICATED as a result of
// displaying insecure content.
- SecurityStyle ran_insecure_content_style;
- SecurityStyle displayed_insecure_content_style;
+ blink::WebSecurityStyle ran_insecure_content_style;
+ blink::WebSecurityStyle displayed_insecure_content_style;
bool scheme_is_cryptographic;
« no previous file with comments | « content/common/security_style_util.cc ('k') | content/public/browser/security_style_explanations.cc » ('j') | no next file with comments »
@@ -52,11 +52,11 @@ struct SecurityStyleExplanations {
// that insecure content has on the overall SecurityStyle of the page;
// for example, a |displayed_insecure_content_style| value of
- // SECURITY_STYLE_UNAUTHENTICATED indicates that the page's overall
- // SecurityStyle will be downgraded to UNAUTHENTICATED as a result of
+ // WebSecurityStyleUnauthenticated indicates that the page's overall
+ // SecurityStyle will be downgraded to Unauthenticated as a result of
// displaying insecure content.

Powered by Google App Engine
This is Rietveld 408576698